Growth Mindset and Pair Programming
===================================

.. index::
   single: growth mindset

Growth Mindset
---------------

Learning to code can be hard at times and sometimes frustrating. However, the feeling you get when your code works is incredible! And your brain grows as you problem solve and debug your programs!

Watch this |video| about the Growth Mindset:

.. |video| raw:: html

   <a href="https://youtu.be/WtKJrB5rOKs" target="_blank">video</a>

.. youtube:: WtKJrB5rOKs
    :height: 400
    :width: 600
    :align: left


To practice using a growth mindset, if you find yourself saying or thinking what's in the left column, try substituting what's in the right column instead:

============================  =======================================
Instead of:                   Try Thinking/Saying:
============================  =======================================
I’m not good at this.         I can learn to do this.
----------------------------  ---------------------------------------
I’m awesome at this.          I’m on the right track.
----------------------------  ---------------------------------------
I give up.                    I’ll use a different learning strategy.
----------------------------  ---------------------------------------
This is too hard.             This may take some time and effort.
----------------------------  ---------------------------------------
I can’t make this any better  I can improve it!
----------------------------  ---------------------------------------
I just can’t do programming.  I’m going to train my brain to do this.
----------------------------  ---------------------------------------
Plan A didn’t work.           Let's try something else.
----------------------------  ---------------------------------------
It’s good enough.             How can I improve this?
============================  =======================================

.. index::
   single: pair programming

Pair Programming
-----------------

In this curriculum, you are encouraged to work together in pairs to complete the programming challenges. **Pair programming** is a successful software development technique where two programmers work together at one computer. One, the driver, types in code while the other, the navigator, gives ideas and feedback. The two coders switch roles frequently. You can also try buddy programming where each person uses their own computer but helps each other while coding. The advantages of pair programming are that two heads are better than one, and pairs usually produce better code with less roadblocks. As future software developers, it's also important to learn to work in teams.

Watch this |video2| about pair programming:

.. |video2| raw:: html

   <a href="https://www.youtube.com/watch?v=q7d_JtyCq1A" target="_blank">video</a>

.. youtube:: q7d_JtyCq1A
    :height: 400
    :width: 600
    :align: left

